Learn R Programming

genderstat (version 0.1.5)

real_data_GPG: Original Data for Gender Pay Gap (GPG)

Description

A dataset containing observed values for the GPG analysis. This data includes metrics for evaluating income disparities between genders across different countries.

Usage

data(real_data_GPG)

Arguments

Format

A data frame with 191 rows and 3 columns:

country

A character vector representing the name of the country.

female_income

A numeric vector representing the per capita female National Income in the respective country.

male_income

A numeric vector representing the per capita male National Income in the respective country.