A dataset containing observed values for the GPG analysis. This data includes metrics for evaluating income disparities between genders across different countries.
data(real_data_GPG)A data frame with 191 rows and 3 columns:
A character vector representing the name of the country.
A numeric vector representing the per capita female National Income in the respective country.
A numeric vector representing the per capita male National Income in the respective country.